import django.contrib.auth.validators
from django.db import migrations, models


def populate_usernames(apps, schema_editor):
    User = apps.get_model("example", "MyUser")
    for u in User.objects.all().iterator():
        if u.um_id:
            u.username = "um_%s" % u.um_id
        else:
            u.username = "user_%s" % u.id
        u.save()


class Migration(migrations.Migration):

    dependencies = [("example", "0008_auto_20180208_1019")]

    operations = [
        migrations.AddField(
            model_name="myuser",
            name="username",
            field=models.CharField(
                null=True,
                error_messages={"unique": "A user with that username already exists."},
                help_text="Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
                max_length=150,
                unique=True,
                validators=[django.contrib.auth.validators.UnicodeUsernameValidator()],
                verbose_name="username",
            ),
        ),
        migrations.RunPython(populate_usernames),
        migrations.AlterField(
            model_name="myuser",
            name="username",
            field=models.CharField(
                error_messages={"unique": "A user with that username already exists."},
                help_text="Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
                max_length=150,
                unique=True,
                validators=[django.contrib.auth.validators.UnicodeUsernameValidator()],
                verbose_name="username",
            ),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-11-10 14:01
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("example", "0005_auto_20171107_1628")]

    operations = [
        migrations.AlterField(
            model_name="myuser",
            name="customer_category",
            field=models.CharField(
                blank=True,
                choices=[
                    ("QUALITY_PARTNER", "quality partner"),
                    ("DEALER", "dealer"),
                    ("ARCHITECT_PLANNER", "architect/planner"),
                    ("HOUSING_SOCIETY", "housing society"),
                    ("PRIVATE_CUSTOMER", "private customer"),
                    ("OTHERS", "others"),
                ],
                max_length=200,
                null=True,
                verbose_name="customer category",
            ),
        ),
        migrations.AlterField(
            model_name="myuser",
            name="title",
            field=models.CharField(
                blank=True,
                choices=[("MR", "Mr."), ("MRS", "Mrs.")],
                max_length=20,
                null=True,
                verbose_name="title",
            ),
        ),
    ]



import re

from django.contrib.auth import logout
from django.utils import translation

from slxauth.utils import get_authenticator


class TokenAuthMiddleware(object):
    def __init__(self, get_response):
        self.get_response = get_response
        # One-time configuration and initialization.

    def __call__(self, request):
        # Code to be executed for each request before
        # the view (and later middleware) are called.

        access_token = None

        if "HTTP_AUTHORIZATION" in request.META:
            m = re.search("Bearer (\\S+)", request.META["HTTP_AUTHORIZATION"])
            if m:
                access_token = m.group(1)
        else:
            access_token = request.COOKIES.get("access_token")
            # expiration_time = request.COOKIES.get('expiration_time')
            # refresh_token = request.COOKIES.get('refresh_token')

        if access_token:
            # update user from fresh token if needed
            if (
                not request.user.is_authenticated
                or access_token != request.user.access_token
            ):
                auth = get_authenticator()
                auth.login_using_token(request, access_token)
        else:
            # logout only access_token based users to keep django-admin login intact
            if request.user.is_authenticated and request.user.access_token:
                logout(request)

        # set language from profile
        if request.user.is_authenticated and request.user.language:
            translation.activate(request.user.language)
            request.session[translation.LANGUAGE_SESSION_KEY] = request.user.language

        response = self.get_response(request)

        # Code to be executed for each request/response after
        # the view is called.

        return response



# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-10-09 15:19
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("example", "0001_initial")]

    operations = [
        migrations.AddField(
            model_name="myuser",
            name="is_customer_admin",
            field=models.BooleanField(default=False, verbose_name="is customer admin"),
        ),
        migrations.AddField(
            model_name="myuser",
            name="language",
            field=models.CharField(
                blank=True, max_length=2, null=True, verbose_name="language"
            ),
        ),
    ]



# Generated by Django 2.0.1 on 2018-06-19 06:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("example", "0010_auto_20180208_2356")]

    operations = [
        migrations.AddField(
            model_name="myuser",
            name="sap_pernr",
            field=models.IntegerField(blank=True, null=True, verbose_name="SAP Pernr"),
        )
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-10-09 15:21
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("example", "0002_auto_20171009_1719")]

    operations = [
        migrations.AddField(
            model_name="myuser",
            name="crm_contact_id",
            field=models.UUIDField(
                blank=True, null=True, verbose_name="CRM contact id"
            ),
        )
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-11-01 17:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("example", "0003_myuser_crm_contact_id")]

    operations = [
        migrations.AddField(
            model_name="myuser",
            name="avatar_attachment_id",
            field=models.IntegerField(
                blank=True, null=True, verbose_name="avatar attachment id"
            ),
        ),
        migrations.AddField(
            model_name="myuser",
            name="company_logo_attachment_id",
            field=models.IntegerField(
                blank=True, null=True, verbose_name="company logo attachment id"
            ),
        ),
        migrations.AddField(
            model_name="myuser",
            name="um_id",
            field=models.IntegerField(
                blank=True, null=True, verbose_name="user management id"
            ),
        ),
    ]



# Generated by Django 2.0.1 on 2018-02-08 22:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("example", "0009_auto_20180208_2347")]

    operations = [
        migrations.RemoveField(model_name="myuser", name="customer_category"),
        migrations.RemoveField(model_name="myuser", name="um_id"),
        migrations.AlterField(
            model_name="myuser",
            name="customer_name",
            field=models.CharField(
                blank=True, max_length=255, null=True, verbose_name="customer name"
            ),
        ),
        migrations.AlterField(
            model_name="myuser",
            name="email",
            field=models.EmailField(
                blank=True, max_length=254, verbose_name="email address"
            ),
        ),
        migrations.AlterField(
            model_name="myuser",
            name="first_name",
            field=models.CharField(
                blank=True, max_length=255, null=True, verbose_name="first name"
            ),
        ),
        migrations.AlterField(
            model_name="myuser",
            name="language",
            field=models.CharField(
                blank=True, max_length=255, null=True, verbose_name="language"
            ),
        ),
        migrations.AlterField(
            model_name="myuser",
            name="last_name",
            field=models.CharField(
                blank=True, max_length=255, null=True, verbose_name="last name"
            ),
        ),
        migrations.AlterField(
            model_name="myuser",
            name="password",
            field=models.CharField(
                blank=True, max_length=128, null=True, verbose_name="password"
            ),
        ),
        migrations.AlterField(
            model_name="myuser",
            name="title",
            field=models.CharField(
                blank=True,
                choices=[("MR", "Mr."), ("MRS", "Mrs.")],
                max_length=255,
                null=True,
                verbose_name="title",
            ),
        ),
    ]



from django.contrib.auth.admin import UserAdmin
from django.utils.translation import gettext_lazy as _

from .forms import UserAddWithoutPasswordForm


class SolarluxUserAdmin(UserAdmin):
    list_display = (
        "email",
        "title",
        "first_name",
        "last_name",
        "customer_no",
        "customer_name",
        "is_staff",
    )
    list_filter = ("is_staff", "is_superuser", "is_active", "groups")
    search_fields = ("first_name", "last_name", "email")
    ordering = ("email",)
    filter_horizontal = ("groups", "user_permissions")
    add_form = UserAddWithoutPasswordForm

    fieldsets = None

    add_fieldsets = (
        (None, {
            'classes': ('wide',),
            'fields': ('username', ),
        }),
    )
